==> alfred_osint-0.2.3.tar.gz: alfred_osint-0.2.3/alfred_osint/lang/it.py <==
# it.py
# Italian

encrypt1 = "Chiave di cifratura in corso..."

title1 = "Grazie mille ai nostri partner!"

disclamer = " Desclaimer: Non tutti i siti e/o i proxy sono garantiti per funzionare! n Utilizzandoti, tieni pienamente conto delle tue azioni"

targetusernames = "I nomi utente di destinazione: "

version = "Versione"

config1 = "Il file di configurazione esiste: "
config2 = "Aggiorna file esistente: "
config3 = "La cartella esiste gia: "
config4 = "Controlla gli aggiornamenti? [Y/n]: ⤷ "
config5 = "Modificare la configurazione? [Y/n]: ⤷ "
config6 = "Cosa vuoi cambiare? ⤷ "
config7 = "Creazione cartella: "
config8 = "La cartella esiste già: "

configOption1 = "[1] Controlla aggiornamenti: "
configOption2 = "[2] Mostra suggerimenti: "
configOption3 = "[3] Percorso di download del sito: "
configOption4 = "[4] Browser: "
configOption5 = "[5] Lingua: "
configOptionA = (
    "[A] Ripulisci Alfred. (In questo modo vengono rimossi i file temporanei)"
)
configOptionB = "[B] Strumenti per sviluppatori."

configOption1Message = "Ok! [verificareaggiornamenti] È impostato per Sì. Passando a No"
configOption2Message = "Ok! [suggerimenti] È impostato per Sì. Passando a No"
configOption3Message = "Nuovo percorso: ⤷ "
configOption4Message = """Tipi supportati:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            Inserisci il codice della tua lingua
            Lingua supportata:
                it = italiano
                en = Inglese
                il = Ebraico
                es = Spagnolo
                fr = francese 
                ar = arabo
                         """
configOptionAMessage = "Fatto!"
configOptionBMessage = "Benvenuto nel menu sviluppatore!"

configOption1Message2 = (
    "Va bene! [verificareaggiornamenti] È impostato per No. Passando a Sì"
)
configOption2Message2 = "Ok! [suggerimenti] È impostato per No. Passando a Sì"
configOptionBMessage2 = (
    "NON dare le seguenti chiavi a nessuno se non a uno sviluppatore Alfred."
)
configOptionBMessage3 = "chiave privata: "
configOptionBMessage4 = "syscrypt: "

target = "Obiettivo del: ⤷ "
browser = "Browser: "

file_not_found = "File not found: {filename}"
permission_denied = "Permission denied for {operation} on {path}"

note = "Nota! "
path = "PERCORSO: ⤷ "
warning1 = "Molti siti non consentono di scaricare i file del sito. Utilizzare a proprio rischio e pericolo."
warning2 = " L'utilizzo del webscraper è piuttosto lento."
warning3 = " Questo è il tuo primo lancio :D Potrebbe essere necessario riavviare Alfred per utilizzare tutti i moduli"
warning4 = " Stai usando un Prerelease di Alfred!"

confirm1 = "Vuoi scaricare immagini/video? [Y/n] ⤷ "
confirm2 = "Eseguire di nuovo?: [Y/n] ⤷ "

prompt1 = "Entra di nuovo nel sito: ⤷ "
prompt2 = "Si prega di segnalare eventuali bug o errori al nostro repository o server Discord. "
prompt3 = "È possibile disabilitare l'aggiornamento nel file di configurazione"
prompt4 = "Unisciti al nostro Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "Ok! Ill chiedere più tardi...."
prompt6 = " Siti non funzionanti..."

download1 = "Scaricare "
updates = "Gli aggiornamenti sono abilitati!"


idk1 = "Non sono sicuro di cosa volessi dire..."
idk2 = "Non sono sicuro di quello che hai in mente. Chiederò più tardi"
idk3 = "Non sono sicuro.... Ma puoi controllare qui: "

scan1 = "Ricerca di siti con:"

status1 = "Funzionante...."
status2 = "Creazione/sovrascrittura del file di salvataggio."
status3 = "Reinstallazione in corso............"
status4 = "Torneremo presto ad Alfred ..."
status5 = "Collaudo....."
status6 = "Fermarsi..... Salvato in captured/working.txt"
status7 = "Arresto in corso........"

save1 = "Risultati salvati in"
save2 = "Risultati salvati su file"

error1 = "Errore di autorizzazione"
error2 = "Tipo Errore"
error3 = "Non riesco a trovare il file di salvataggio!"
error4 = "La directory non esiste."
error5 = "Impossibile trovare i file necessari. Tentativo di reinstallare Alfred"
error6 = "Uh oh errore! Sembra che la connessione non sembri funzionare. Controlla la tua connessione o il proxy, quindi riprova:"
error7 = "Impossibile trovare il file del sito"
error8 = "Errore durante il download del contenuto Web!"
error9 = "Errore con il file del sito"
error10 = "Selezione del driver Web non valida."
error11 = "Si è verificato un errore: "

fileshare1 = "[*] Ascolto come"
fileshare2 = "è connesso."
fileshare3 = "Ricettazione"

wikiOption1 = "[1] Installazione"
wikiOption2 = "[2] Opzioni"
wikiOption3 = "[3] Errori"
wikiOption4 = "[4] Alfred Oscuro"
wikiOption5 = "[5] Moduli"

wikilist = "Puoi trovare informazioni su di esso qui: "

rqUname = "Nome utente richiesto: "

sender1 = "[+] Connessione a"
sender2 = "[+] Connesso."
sender3 = "Invio in corso."
sender4 = "File da inviare: ⤷ "

fs1 = "Server host? [Y/n]: ⤷ "
fs2 = "In attesa di connettersi all'host!"
fs3 = "In attesa che il client si connetta!"

siteDl1 = "Totale file di script nella pagina:"
siteDl2 = "Totale file CSS nella pagina:"
# example bc imma forget
# import messages

# print(messages.title)  # Output: Hello, World!
# print(messages.text1)  # Output: This is a sample message.

# # Example of using placeholders in messages
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))

==> alfred_osint-0.2.3.4.tar.gz: alfred_osint-0.2.3.4/alfred_osint/lang/it.py <==
# it.py
# Italian

encrypt1 = "Chiave di cifratura in corso..."

title1 = "Grazie mille ai nostri partner!"

disclamer = " Desclaimer: Non tutti i siti e/o i proxy sono garantiti per funzionare! n Utilizzandoti, tieni pienamente conto delle tue azioni"

targetusernames = "I nomi utente di destinazione: "

version = "Versione"

config1 = "Il file di configurazione esiste "
config2 = "Aggiorna file esistente "
config3 = "La cartella esiste gia: "
config4 = "Controlla gli aggiornamenti? [Y/n]: ⤷ "
config5 = "Modificare la configurazione? [Y/n]: ⤷ "
config6 = "Cosa vuoi cambiare? ⤷ "
config7 = "Creazione cartella: "
config8 = "La cartella esiste già: "

configOption1 = "[1] Controlla aggiornamenti: "
configOption2 = "[2] Mostra suggerimenti: "
configOption3 = "[3] Percorso di download del sito: "
configOption4 = "[4] Browser: "
configOption5 = "[5] Lingua: "
configOptionA = (
    "[A] Ripulisci Alfred. (In questo modo vengono rimossi i file temporanei)"
)
configOptionB = "[B] Strumenti per sviluppatori."

configOption1Message = "Ok! [verificareaggiornamenti] È impostato per Sì. Passando a No"
configOption2Message = "Ok! [suggerimenti] È impostato per Sì. Passando a No"
configOption3Message = "Nuovo percorso: ⤷ "
configOption4Message = """Tipi supportati:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            Inserisci il codice della tua lingua
            Lingua supportata:
                it = italiano
                en = Inglese
                il = Ebraico
                es = Spagnolo
                fr = francese 
                ar = arabo
                de = tedesco
                ru = Russo
                hi = Hindi
                         """
configOptionAMessage = "Fatto!"
configOptionBMessage = "Benvenuto nel menu sviluppatore!"

configOption1Message2 = (
    "Va bene! [verificareaggiornamenti] È impostato per No. Passando a Sì"
)
configOption2Message2 = "Ok! [suggerimenti] È impostato per No. Passando a Sì"
configOptionBMessage2 = (
    "NON dare le seguenti chiavi a nessuno se non a uno sviluppatore Alfred."
)
configOptionBMessage3 = "chiave privata: "
configOptionBMessage4 = "syscrypt: "

target = "Obiettivo del: ⤷ "
browser = "Browser: "

file_not_found = "File not found: {filename}"
permission_denied = "Permission denied for {operation} on {path}"

note = "Nota! "
path = "PERCORSO: ⤷ "
warning1 = "Molti siti non consentono di scaricare i file del sito. Utilizzare a proprio rischio e pericolo."
warning2 = " L'utilizzo del webscraper è piuttosto lento."
warning3 = " Questo è il tuo primo lancio :D Potrebbe essere necessario riavviare Alfred per utilizzare tutti i moduli"
warning4 = " Stai usando un Prerelease di Alfred!"

confirm1 = "Vuoi scaricare immagini/video? [Y/n] ⤷ "
confirm2 = "Eseguire di nuovo?: [Y/n] ⤷ "

prompt1 = "Entra di nuovo nel sito: ⤷ "
prompt2 = "Si prega di segnalare eventuali bug o errori al nostro repository o server Discord. "
prompt3 = "È possibile disabilitare l'aggiornamento nel file di configurazione"
prompt4 = "Unisciti al nostro Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "Ok! Ill chiedere più tardi...."
prompt6 = " Siti non funzionanti..."

download1 = "Scaricare "
updates = "Gli aggiornamenti sono abilitati!"


idk1 = "Non sono sicuro di cosa volessi dire..."
idk2 = "Non sono sicuro di quello che hai in mente. Chiederò più tardi"
idk3 = "Non sono sicuro.... Ma puoi controllare qui: "

scan1 = "Ricerca di siti con:"

status1 = "Funzionante...."
status2 = "Creazione/sovrascrittura del file di salvataggio."
status3 = "Reinstallazione in corso............"
status4 = "Torneremo presto ad Alfred ..."
status5 = "Collaudo....."
status6 = "Fermarsi..... Salvato in captured/working.txt"
status7 = "Arresto in corso........"

save1 = "Risultati salvati in"
save2 = "Risultati salvati su file"

error1 = "Errore di autorizzazione"
error2 = "Tipo Errore"
error3 = "Non riesco a trovare il file di salvataggio!"
error4 = "La directory non esiste."
error5 = "Impossibile trovare i file necessari. Tentativo di reinstallare Alfred"
error6 = "Uh oh errore! Sembra che la connessione non sembri funzionare. Controlla la tua connessione o il proxy, quindi riprova:"
error7 = "Impossibile trovare il file del sito"
error8 = "Errore durante il download del contenuto Web!"
error9 = "Errore con il file del sito"
error10 = "Selezione del driver Web non valida."
error11 = "Si è verificato un errore: "

fileshare1 = "[*] Ascolto come"
fileshare2 = "è connesso."
fileshare3 = "Ricettazione"

wikiOption1 = "[1] Installazione"
wikiOption2 = "[2] Opzioni"
wikiOption3 = "[3] Errori"
wikiOption4 = "[4] Alfred Oscuro"
wikiOption5 = "[5] Moduli"

wikilist = "Puoi trovare informazioni su di esso qui: "

rqUname = "Nome utente richiesto: "

sender1 = "[+] Connessione a"
sender2 = "[+] Connesso."
sender3 = "Invio in corso."
sender4 = "File da inviare: ⤷ "

fs1 = "Server host? [Y/n]: ⤷ "
fs2 = "In attesa di connettersi all'host!"
fs3 = "In attesa che il client si connetta!"

siteDl1 = "Totale file di script nella pagina:"
siteDl2 = "Totale file CSS nella pagina:"
# example bc imma forget
# import messages

# print(messages.title)  # Output: Hello, World!
# print(messages.text1)  # Output: This is a sample message.

# # Example of using placeholders in messages
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))
